Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2073)

Unified Diff: content/child/web_url_request_util.h

Issue 2954343005: Merge ResourceRequestBodyImpl and ResourceRequestBody. (Closed)
Patch Set: Remove comment Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/child/web_url_loader_impl.cc ('k') | content/child/web_url_request_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/child/web_url_request_util.h
diff --git a/content/child/web_url_request_util.h b/content/child/web_url_request_util.h
index 050aae17e3ffc932f0f2cd658c83e498580c6d25..2374782c8fd9a257d0eeaea17ff3060bd90f4481 100644
--- a/content/child/web_url_request_util.h
+++ b/content/child/web_url_request_util.h
@@ -8,10 +8,10 @@
#include <string>
#include "content/common/content_export.h"
-#include "content/common/resource_request_body_impl.h"
#include "content/common/service_worker/service_worker_types.h"
#include "content/public/common/request_context_frame_type.h"
#include "content/public/common/request_context_type.h"
+#include "content/public/common/resource_request_body.h"
#include "content/public/common/resource_type.h"
#include "third_party/WebKit/public/platform/WebMixedContentContextType.h"
@@ -31,18 +31,18 @@ std::string GetWebURLRequestHeaders(const blink::WebURLRequest& request);
int GetLoadFlagsForWebURLRequest(const blink::WebURLRequest& request);
// Takes a ResourceRequestBodyImpl and converts into WebHTTPBody.
blink::WebHTTPBody GetWebHTTPBodyForRequestBody(
- const scoped_refptr<ResourceRequestBodyImpl>& input);
+ const scoped_refptr<ResourceRequestBody>& input);
-// Takes a WebHTTPBody and converts into a ResourceRequestBodyImpl.
-scoped_refptr<ResourceRequestBodyImpl> GetRequestBodyForWebHTTPBody(
+// Takes a WebHTTPBody and converts into a ResourceRequestBody.
+scoped_refptr<ResourceRequestBody> GetRequestBodyForWebHTTPBody(
const blink::WebHTTPBody& httpBody);
// Takes a WebURLRequest and sets the appropriate information
// in a ResourceRequestBodyImpl structure. Returns an empty scoped_refptr
// if the request body is not present.
-scoped_refptr<ResourceRequestBodyImpl> GetRequestBodyForWebURLRequest(
+scoped_refptr<ResourceRequestBody> GetRequestBodyForWebURLRequest(
const blink::WebURLRequest& request);
// Helper functions to convert enums from the blink type to the content
« no previous file with comments | « content/child/web_url_loader_impl.cc ('k') | content/child/web_url_request_util.cc » ('j') | no next file with comments »
@@ -31,18 +31,18 @@ std::string GetWebURLRequestHeaders(const blink::WebURLRequest& request);
int GetLoadFlagsForWebURLRequest(const blink::WebURLRequest& request);
-// Takes a ResourceRequestBodyImpl and converts into WebHTTPBody.
+// Takes a ResourceRequestBody and converts into WebHTTPBody.
blink::WebHTTPBody GetWebHTTPBodyForRequestBody(
@@ -31,18 +31,18 @@ std::string GetWebURLRequestHeaders(const blink::WebURLRequest& request);
const blink::WebHTTPBody& httpBody);
// Takes a WebURLRequest and sets the appropriate information
-// in a ResourceRequestBodyImpl structure. Returns an empty scoped_refptr
+// in a ResourceRequestBody structure. Returns an empty scoped_refptr
// if the request body is not present.

Powered by Google App Engine
This is Rietveld 408576698